==> jc-1.4.0.tar.gz: soot/toolkits/graph/SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer.h <==
// class soot.toolkits.graph.SlowPseudoTopologicalOrderer$PseudoTopologicalReverseOrderer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 906d4f68d80a632a soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer_H_
#define _JC_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object;
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__241$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_refs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_refs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_nonrefs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$refs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$refs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$nonrefs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$nonrefs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object;

typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$fields_struct	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$fields_struct;
typedef const struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vmethods	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vmethods;
typedef const struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtable	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtable;
typedef const struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtype	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtype;

// Class fields structure
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$fields_struct {
	jint	BLACK;
	jint	GRAY;
	jint	WHITE;
};
extern _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$fields_struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$class_fields;

// Constructors
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method$_init$70ecbf17e544d3bf(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *);
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method$_init$4a7e3c52596ff505(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__241$object *);

// Virtual methods
extern struct _jc_java_util_LinkedList$object *_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method$computeOrder$e99ef79fd26f3ec8(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method$newList$4c736451834ee04d(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_object *);
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method$visitNode$76904f2e0e29deb5(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method_info$computeOrder$e99ef79fd26f3ec8;
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method_info$newList$4c736451834ee04d;
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method_info$visitNode$76904f2e0e29deb5;

// Virtual methods structure
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vmethods {
	struct _jc_java_util_LinkedList$object	*(*computeOrder$e99ef79fd26f3ec8)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_object *);
	struct _jc_object	*(*newList$4c736451834ee04d)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_object *);
	void	(*visitNode$76904f2e0e29deb5)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vmethods	soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer;
};

// Vtype
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_refs {
	struct _jc_object	*stmtToColor;
	struct _jc_java_util_LinkedList$object	*order;
	struct _jc_object	*graph;
	struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$refs {
    _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_refs	soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_nonrefs {
	jboolean	mIsReversed;
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_nonrefs	soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer;
};

// Object instance structure
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object {
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtype	*vtype;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtype _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$class_object;

#endif	/* _JC_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/graph/SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer.h <==
// class soot.toolkits.graph.SlowPseudoTopologicalOrderer$PseudoTopologicalReverseOrderer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 906d4f68d80a632a soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer_H_
#define _JC_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object;
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__241$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_refs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_refs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_nonrefs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$refs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$refs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$nonrefs	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$nonrefs;
typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object;

typedef struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$fields_struct	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$fields_struct;
typedef const struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vmethods	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vmethods;
typedef const struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtable	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtable;
typedef const struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtype	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtype;

// Class fields structure
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$fields_struct {
	jint	BLACK;
	jint	GRAY;
	jint	WHITE;
};
extern _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$fields_struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$class_fields;

// Constructors
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method$_init$70ecbf17e544d3bf(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method$_init$4a7e3c52596ff505(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_LinkedList$object *_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method$computeOrder$e99ef79fd26f3ec8(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method$newList$4c736451834ee04d(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method$visitNode$76904f2e0e29deb5(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method_info$computeOrder$e99ef79fd26f3ec8;
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method_info$newList$4c736451834ee04d;
extern _jc_method _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$method_info$visitNode$76904f2e0e29deb5;

// Virtual methods structure
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vmethods {
	struct _jc_java_util_LinkedList$object	*(*computeOrder$e99ef79fd26f3ec8)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*newList$4c736451834ee04d)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*visitNode$76904f2e0e29deb5)(_jc_env *, struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vmethods	soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer;
};

// Vtype
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_refs {
	struct _jc_object	*stmtToColor;
	struct _jc_java_util_LinkedList$object	*order;
	struct _jc_object	*graph;
	struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$refs {
    _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_refs	soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_nonrefs {
	jboolean	mIsReversed;
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$sub_nonrefs	soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer;
};

// Object instance structure
struct _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$object {
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtype	*vtype;
	_jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$vtype _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer$class_object;

#endif	/* _JC_soot_toolkits_graph_SlowPseudoTopologicalOrderer__24PseudoTopologicalReverseOrderer_H_ */
